@@ -13,7 +13,7 @@ use base 'DBM::Deep';
 use Scalar::Util ();
 
 sub _get_self {
-    eval { local $SIG{'__DIE__'}; tied( @{$_[0]} ) } || $_[0]
+    eval { tied( @{$_[0]} ) } || $_[0]
 }
 
 sub TIEARRAY {
@@ -76,7 +76,7 @@ sub STORE {
         $key = pack($DBM::Deep::LONG_PACK, $key);
     }
 
-    my $rv = $self->SUPER::STORE( $key, $value, $orig );
+    my $rv = $self->SUPER::STORE( $key, $value );
 
     if ( $numeric_idx && $rv == 2 ) {
         $size = $self->FETCHSIZE unless defined $size;
@@ -136,7 +136,7 @@ sub DELETE {
         $key = pack($DBM::Deep::LONG_PACK, $key);
     }
 
-    my $rv = $self->SUPER::DELETE( $key, $unpacked_key );
+    my $rv = $self->SUPER::DELETE( $key );
 
 	if ($rv && $unpacked_key == $size - 1) {
 		$self->STORESIZE( $unpacked_key );
@@ -155,12 +155,12 @@ sub FETCHSIZE {
 
     $self->lock( $self->LOCK_SH );
 
-	my $SAVE_FILTER = $self->_root->{filter_fetch_value};
-	$self->_root->{filter_fetch_value} = undef;
+	my $SAVE_FILTER = $self->root->{filter_fetch_value};
+	$self->root->{filter_fetch_value} = undef;
 	
 	my $packed_size = $self->FETCH('length');
 	
-	$self->_root->{filter_fetch_value} = $SAVE_FILTER;
+	$self->root->{filter_fetch_value} = $SAVE_FILTER;
 	
     $self->unlock;
 
@@ -180,12 +180,12 @@ sub STORESIZE {
 	
     $self->lock( $self->LOCK_EX );
 
-	my $SAVE_FILTER = $self->_root->{filter_store_value};
-	$self->_root->{filter_store_value} = undef;
+	my $SAVE_FILTER = $self->root->{filter_store_value};
+	$self->root->{filter_store_value} = undef;
 	
 	my $result = $self->STORE('length', pack($DBM::Deep::LONG_PACK, $new_length));
 	
-	$self->_root->{filter_store_value} = $SAVE_FILTER;
+	$self->root->{filter_store_value} = $SAVE_FILTER;
 	
     $self->unlock;
 
@@ -310,8 +310,7 @@ sub SPLICE {
 	##
 	# Calculate offset and length of splice
 	##
-	my $offset = shift;
-    $offset = 0 unless defined $offset;
+	my $offset = shift || 0;
 	if ($offset < 0) { $offset += $length; }
 	
 	my $splice_length;
